Structs
- The JSON response.
- The JSON response formatter.
- The plain text response formatter.
- The input text to speech.
- The request body for the
/audio/speechendpoint. - The speed to speech.
- The SubRip Subtitle response formatter.
- The request body for the
/audio/transcriptionsendpoint. - The request boyd for the
/audio/translationsendpoint. - The verbose JSON response.
- The verbose JSON response formatter.
- The WebVTT response formatter.
Enums
- The error of an audio API calling.
- The models for audio APIs.
- The audio file to be used for the request.
- The ISO 639-1 Language Codes.
- The text-to-speech models.
- The response format of a speech audio.
- The error of a speech stream.
- The error of formatting a response text.
- The timestamp granularity for the result of the transcription.
- The voice of a text-to-speech.
Traits
- A format of a response text.
- A formatter of a response text to a specific type:
<T>.
Type Aliases
- The result of an audio API calling.
- The result of a speech stream.