Struct oaapi::chat::ChatCompletionObject
source · pub struct ChatCompletionObject {
pub id: String,
pub choices: Vec<ChatCompletionChoice>,
pub created: u64,
pub model: ChatModel,
pub system_fingerprint: Option<String>,
pub object: String,
pub usage: Usage,
}Expand description
The chat completion object.
Fields
id: StringA unique identifier for the chat completion.
choices: Vec<ChatCompletionChoice>A list of chat completion choices. Can be more than one if n is greater than 1.
created: u64The Unix timestamp (in seconds) of when the chat completion was created.
model: ChatModelThe model used for the chat completion.
system_fingerprint: Option<String>This fingerprint represents the backend configuration that the model runs with.
Can be used in conjunction with the seed request parameter to understand when backend changes have been made that might impact determinism.
object: StringThe object type, which is always chat.completion.
usage: UsageUsage statistics for the completion request.